summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmmediaedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmmediaedit.h')
-rw-r--r--kpovmodeler/pmmediaedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmmediaedit.h b/kpovmodeler/pmmediaedit.h
index 021a5b77..275d7029 100644
--- a/kpovmodeler/pmmediaedit.h
+++ b/kpovmodeler/pmmediaedit.h
@@ -44,9 +44,9 @@ class PMMediaEdit : public PMTextureBaseEdit
typedef PMTextureBaseEdit Base;
public:
/**
* Creates a PMMediaEdit with tqparent and name
*/
- PMMediaEdit( TQWidget* tqparent, const char* name = 0 );
+ PMMediaEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -44,9 +44,9 @@ class PMMediaEdit : public PMTextureBaseEdit
public:
/**
- * Creates a PMMediaEdit with tqparent and name
+ * Creates a PMMediaEdit with parent and name
*/